embedded

package
v0.0.0-...-6e8e7e3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: Apache-2.0, BSD-3-Clause Imports: 0 Imported by: 1

README

Trace Embedded

PkgGoDev

Documentation

Overview

Package embedded provides interfaces embedded within the OpenTelemetry trace API.

Implementers of the OpenTelemetry trace API can embed the relevant type from this package into their implementation directly. Doing so will result in a compilation error for users when the OpenTelemetry trace API is extended (which is something that can happen without a major version bump of the API package).

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Span

type Span interface {
	// contains filtered or unexported methods
}

Span is embedded in github.com/hanzoai/telemetry-go/trace.Span.

Embed this interface in your implementation of the github.com/hanzoai/telemetry-go/trace.Span if you want users to experience a compilation error, signaling they need to update to your latest implementation, when the github.com/hanzoai/telemetry-go/trace.Span interface is extended (which is something that can happen without a major version bump of the API package).

type Tracer

type Tracer interface {
	// contains filtered or unexported methods
}

Tracer is embedded in github.com/hanzoai/telemetry-go/trace.Tracer.

Embed this interface in your implementation of the github.com/hanzoai/telemetry-go/trace.Tracer if you want users to experience a compilation error, signaling they need to update to your latest implementation, when the github.com/hanzoai/telemetry-go/trace.Tracer interface is extended (which is something that can happen without a major version bump of the API package).

type TracerProvider

type TracerProvider interface {
	// contains filtered or unexported methods
}

TracerProvider is embedded in github.com/hanzoai/telemetry-go/trace.TracerProvider.

Embed this interface in your implementation of the github.com/hanzoai/telemetry-go/trace.TracerProvider if you want users to experience a compilation error, signaling they need to update to your latest implementation, when the github.com/hanzoai/telemetry-go/trace.TracerProvider interface is extended (which is something that can happen without a major version bump of the API package).

Jump to